fileutil

package module
v0.0.0-...-021e927 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 30, 2020 License: MPL-2.0 Imports: 3 Imported by: 4

README

fileutil

file and dir utilities in golang

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func AllSubfolders

func AllSubfolders(dir string) ([]string, error)

AllSubfolders gets all subfolders under given dir. Hidden folders are ignored.

func Exists

func Exists(path string) bool

Exists reports whether the given path exists.

func IsDir

func IsDir(path string) bool

IsDir checks whether the given path is a directory.

func IsFile

func IsFile(path string) bool

IsFile checks whether the given path is a regular file

func IsHiddenFile

func IsHiddenFile(f os.FileInfo) bool

IsHiddenFile checks whether the file is hidden, that's, starts with ".".

func IsSymlink(path string) bool

IsSymlink checks whether the given path is a regular file

Types

This section is empty.

Jump to